@@ -8,12 +8,9 @@ $.urlParam = function(name){
 
 window.onload = function() {
     var lang = $.urlParam('lang');
-    if (lang === "undefined") {
-        document.getElementById("title-head").innerHTML = $("p.title.lang-default").text();
-    }
-    else {
+    if (lang !== "undefined") {
         document.getElementById("title-head").innerHTML = $("p.title.lang-" + lang).text();
         $(".lang-default").css("display", "none");
         $(".lang-" + lang).css("display", "block");
     }
-};
\ No newline at end of file
+};
